@@ -170,11 +170,14 @@ def database_exists(url):
             return False
 
 
-def create_database(url, encoding='utf8'):
+def create_database(url, encoding='utf8', template=None):
     """Issue the appropriate CREATE DATABASE statement.
 
     :param url: A SQLAlchemy engine URL.
     :param encoding: The encoding to create the database as.
+    :param template:
+        The name of the template from which to create the new database. At the
+        moment only supported by PostgreSQL driver.
 
     To create a database, you can pass a simple URL that would have
     been passed to ``create_engine``. ::
@@ -204,10 +207,15 @@ def create_database(url, encoding='utf8'):
         if engine.driver == 'psycopg2':
             from psycopg2.extensions import ISOLATION_LEVEL_AUTOCOMMIT
             engine.raw_connection().set_isolation_level(
-                ISOLATION_LEVEL_AUTOCOMMIT)
+                ISOLATION_LEVEL_AUTOCOMMIT
+            )
 
-        text = "CREATE DATABASE %s ENCODING '%s' TEMPLATE template0" % (
-            database, encoding)
+        if not template:
+            template = 'template0'
+
+        text = "CREATE DATABASE %s ENCODING '%s' TEMPLATE %s" % (
+            database, encoding, template
+        )
         engine.execute(text)
 
     elif engine.dialect.name == 'mysql':
